<?php
require_once '../../../datab.php'; // Adjust the path to your database connection file as needed

$response = [];

// Check if the request method is POST
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Validate and sanitize input data
    $id = filter_input(INPUT_POST, 'id', FILTER_SANITIZE_NUMBER_INT);
    $startTime = filter_input(INPUT_POST, 'startTime', FILTER_SANITIZE_STRING);
    $endTime = filter_input(INPUT_POST, 'endTime', FILTER_SANITIZE_STRING);

    // Validate input (you may add more validation as per your application logic)
    if (!$id || !$startTime || !$endTime) {
        http_response_code(400); // Bad request
        $response['status'] = 'error';
        $response['message'] = 'Invalid input data.';
        echo json_encode($response);
        exit;
    }

    // Prepare the SQL statement to update patient_drip
    $stmt = $conn->prepare("UPDATE patient_drip SET start_time = ?, end_time = ?, status = 'active' WHERE id = ?");
    if ($stmt) {
        // Bind the parameters
        $stmt->bind_param('ssi', $startTime, $endTime, $id);

        // Execute the statement
        if ($stmt->execute()) {
            $response['status'] = 'success';
            $response['message'] = 'Drip timer updated successfully';

            // Fetch updated data from the database
            $selectStmt = $conn->prepare("SELECT * FROM patient_drip WHERE id = ?");
            $selectStmt->bind_param('i', $id);
            $selectStmt->execute();
            $result = $selectStmt->get_result();

            if ($result->num_rows > 0) {
                $row = $result->fetch_assoc();
                $response['data'] = [
                    'id' => $row['id'],
                    'patient_name' => '',
                    'mrd_no' => '',
                    'drip_id' => $row['drip_id'],
                    'start_time' => $row['start_time'],
                    'end_time' => $row['end_time'],
                    'status' => $row['status'] // Include the status in the response
                ];
            } else {
                $response['status'] = 'error';
                $response['message'] = 'Failed to fetch updated drip data.';
            }

            $selectStmt->close();
        } else {
            $response['status'] = 'error';
            $response['message'] = 'Failed to update drip timer: ' . $stmt->error;
        }

        // Close the statement
        $stmt->close();
    } else {
        $response['status'] = 'error';
        $response['message'] = 'Database error: ' . $conn->error;
    }

    // Close the connection
    $conn->close();

    // Return the response as JSON
    header('Content-Type: application/json');
    echo json_encode($response);
} else {
    // If the request method is not POST, return an error response
    http_response_code(405); // Method Not Allowed
    $response['status'] = 'error';
    $response['message'] = 'Only POST method allowed.';
    echo json_encode($response);
}
?>
