<?php
require_once '../../../datab.php';

// Check if the id, name, and count parameters are set
if (isset($_POST['id'], $_POST['name'], $_POST['count'])) {
    $requestId = intval($_POST['id']);
    $tabletName = $_POST['name'];
    $tabletCount = intval($_POST['count']);

    // Fetch the current status for the specified request ID from the medicine_requests table
    $stmt = $conn->prepare("SELECT status FROM medicine_requests WHERE id = ?");
    $stmt->bind_param("i", $requestId);
    $stmt->execute();
    $stmt->bind_result($status);
    $stmt->fetch();
    $stmt->close();

    if ($status !== null) {
        if ($status === 'added') {
            $response = [
                'status' => 'Error',
                'message' => 'Tablet has already been added'
            ];
        }
        else if ($status === 'Approved') {
            // Fetch the current quantity from inventory_ward
            $stmt = $conn->prepare("SELECT quantity FROM inventory_ward WHERE medicine_id = (SELECT id FROM tablet_data WHERE tablet_name = ?)");
            $stmt->bind_param("s", $tabletName);
            $stmt->execute();
            $stmt->bind_result($currentQuantity);
            $stmt->fetch();
            $stmt->close();

            if ($currentQuantity !== null) {
                // Update the new quantity in inventory_ward
                $newQuantity = $currentQuantity + $tabletCount;
                $stmtUpdate = $conn->prepare("UPDATE inventory_ward SET quantity = ? WHERE medicine_id = (SELECT id FROM tablet_data WHERE tablet_name = ?)");
                $stmtUpdate->bind_param("is", $newQuantity, $tabletName);

                if ($stmtUpdate->execute()) {
                    // Update the status in medicine_requests to 'added'
                    $stmtStatus = $conn->prepare("UPDATE medicine_requests SET status = 'added' WHERE id = ?");
                    $stmtStatus->bind_param("i", $requestId);

                    if ($stmtStatus->execute()) {
                        $response = [
                            'status' => 'Success',
                            'message' => 'Tablet added successfully'
                        ];
                    } else {
                        $response = [
                            'status' => 'Error',
                            'message' => 'Failed to update status in medicine_requests'
                        ];
                    }
                    $stmtStatus->close();
                } else {
                    $response = [
                        'status' => 'Error',
                        'message' => 'Failed to update quantity in inventory_ward'
                    ];
                }
                $stmtUpdate->close();
            } else {
                $response = [
                    'status' => 'Error',
                    'message' => 'Tablet not found in inventory_ward'
                ];
            }
        } else {
            $response = [
                'status' => 'Error',
                'message' => 'Tablet request is not approved'
            ];
        }
    } else {
        $response = [
            'status' => 'Error',
            'message' => 'Tablet request not found or status is null'
        ];
    }
} else {
    $response = [
        'status' => 'Error',
        'message' => 'ID, name, or count parameter is missing'
    ];
}

echo json_encode($response);
?>
