<?php
session_start();
require_once '../../../datab.php';

// Set headers to JSON
header('Content-Type: application/json');

// Initialize response array
$res = [];

// Get pagination and search parameters
$pg_no = isset($_GET['pg_no']) ? (int)$_GET['pg_no'] : 1; // Current page number, default is 1
$limit = 10; // Number of records per page
$offset = ($pg_no - 1) * $limit; // Calculate offset for SQL query
$search = isset($_GET['search']) ? $conn->real_escape_string($_GET['search']) : ''; // Search query

$floor_id = $_SESSION['floor_id'];

// Count total records for pagination
$sql_count = "SELECT COUNT(*) as total 
              FROM inventory_ward iw
              JOIN tablet_data td ON iw.medicine_id = td.id
              JOIN tablet_dosage_price tdp ON iw.medicine_id = tdp.tablet_id AND iw.dosage_id = tdp.id
              JOIN medicine_company_data mcd ON td.company_id = mcd.id
              WHERE iw.floor_id = '$floor_id'
              AND (td.tablet_name LIKE '%$search%' OR mcd.company_name LIKE '%$search%')";
$result_count = $conn->query($sql_count);
$total_count = $result_count->fetch_assoc()['total'];
$total_pages = ceil($total_count / $limit); // Calculate total pages

// Query with pagination and search functionality
$sql = "SELECT iw.medicine_id, iw.dosage_id, iw.quantity, td.tablet_name, td.type, tdp.dosage, tdp.price, td.company_id, mcd.company_name,
               (iw.quantity * tdp.price) AS stock_value
        FROM inventory_ward iw
        JOIN tablet_data td ON iw.medicine_id = td.id
        JOIN tablet_dosage_price tdp ON iw.medicine_id = tdp.tablet_id AND iw.dosage_id = tdp.id
        JOIN medicine_company_data mcd ON td.company_id = mcd.id
        WHERE iw.floor_id = '$floor_id'
        AND (td.tablet_name LIKE '%$search%' OR mcd.company_name LIKE '%$search%')
        ORDER BY iw.medicine_id DESC
        LIMIT $limit OFFSET $offset";

$result = $conn->query($sql);

if ($result) {
    if ($result->num_rows > 0) {
        $data = [];
        while ($row = mysqli_fetch_assoc($result)) {
            $data[] = $row;
        }
        $res = [
            'status' => 'Success',
            'data' => $data,
            'current_page' => $pg_no,
            'total_pages' => $total_pages,
            'total_count' => $total_count
        ];
    } else {
        $res = ['status' => 'Error', 'message' => 'No medicine data found.'];
    }
} else {
    $res = ['status' => 'Error', 'message' => 'Query execution failed: ' . $conn->error];
}

// Close the database connection
$conn->close();

// Output JSON response
echo json_encode($res);
?>
