<?php
require_once '../../../datab.php'; // Adjust the path as needed

// Initialize response array
$response = [];

// Check if the request method is POST
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Validate and sanitize input data
    $id = filter_input(INPUT_POST, 'id', FILTER_SANITIZE_NUMBER_INT);

    // Validate input (you may add more validation as per your application logic) 
    if (!$id) {
        http_response_code(400); 
        $response['status'] = 'error';
        $response['message'] = 'Invalid input data.';
        echo json_encode($response);
        exit;
    }

    // Get the current timestamp for end_time
    $endTime = date('H:i'); // Adjust format if needed based on your database schema

    // Prepare SQL statement to update drip record
    $sql = "UPDATE patient_drip SET end_time = ?, status = 'finished' WHERE id = ?";
    $stmt = $conn->prepare($sql);

    if ($stmt) {
        // Bind parameters
        $stmt->bind_param('si', $endTime, $id);
        
        // Execute the statement
        if ($stmt->execute()) {
            $response['status'] = 'success';
            $response['message'] = 'Drip status and end time updated successfully';
        } else {
            $response['status'] = 'error';
            $response['message'] = 'Failed to update drip status and end time: ' . $stmt->error;
        }

        // Close statement
        $stmt->close();
    } else {
        $response['status'] = 'error';
        $response['message'] = 'Database error: ' . $conn->error;
    }

    // Close connection
    $conn->close();
} else {
    // If the request method is not POST, return an error response
    http_response_code(405); // Method Not Allowed
    $response['status'] = 'error';
    $response['message'] = 'Only POST method allowed.';
}

// Return JSON response
header('Content-Type: application/json');
echo json_encode($response);
?>
